<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="hu">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Alkalmazás proxy</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy típusa</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP cím</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcionális</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>A konfigurálás után jelölje be az Indító alkalmazás helyi menüjében a &quot;Proxy használata&quot; lehetőséget</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Érvénytelen IP cím</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Érvénytelen port</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Szétkapcsolás</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Törlés</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Kapcsolódás</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Szétkapcsolás</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Biztosan törölni szeretné ezt a beállítást?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Vezetékes kapcsolat %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Vezeték nélküli kapcsolat %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE kapcsolat %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Új VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN típusa</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Exportálás</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Alkalmazás proxy</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Személyes Hotspot</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Hálózati adatok</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Rendszer proxy</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Vezetékes hálózat </translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Vezetékes hálózati kártya</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Hálózati kapcsolat hozzáadása</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Vezeték nélküli kártya</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Csatlakozás rejtett hálózathoz</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE kapcsolat létrehozása</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN állapota</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN létrehozása</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN beállítások importálása</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy típusa</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurációs URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP cím</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot létrehozása</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Felület</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC cím</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Sáv</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Elsődleges DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Hálózati maszk</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Előtag</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Sebesség</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation>A repülőgép üzemmód engedélyezése kikapcsolja a vezeték nélküli hálózatot, a személyes hotspotot és a Bluetooth-t</translation>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation>DNS</translation>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Érvénytelen DNS cím</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Vezetékes hálózat</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nem kötött</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Eszköz MAC címe</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klónozott MAC cím</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU testreszabása</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Létező név</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automata csatlakozás</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Beállítások hozzáadása</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Hotspot létrehozása</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP cím</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Duplikált IP cím</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Érvénytelen IP cím</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Érvénytelen hálózati maszk</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Csak egy átjáró engedélyezett</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Hálózati maszk</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation>Duplikált IP cím</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Érvénytelen IP cím</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation>Csak egy átjáró engedélyezett</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Előtag</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Kihagyás</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP cím</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Csak a megfelelő forrásokban alkalmazzuk</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Eljárás</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Hálózati maszk</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Előtag</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Érvénytelen IP cím</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Érvénytelen hálózati maszk</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Eljárás</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Kihagyás</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Hálózati adatok</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Rendszer proxy</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Alkalmazás proxy</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Repülőgép üzemmód</translation>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Hálózati adatok</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Hálózat</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>IP cím ütközés</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Letiltva</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation>A Hálózati Kezelő által konfigurálva</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Személyes Hotspot</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Szolgáltatás</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nincs BSD Adattömörítés</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nincs Delflate adattömörítés </translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nincs TCP fejléc tömörítés</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nincs protokoll mező tömörítés</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nincs cím/vezérlés tömörítés</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo csomagok küldése</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE használata</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128 bites MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Állapotfüggő MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>PPPoE kapcsolat létrehozása</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Rendszer proxy</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Mégsem</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Mentés</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy típusa</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Manuális</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Opcionális</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP Proxy</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS Proxy</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP Proxy</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS Proxy</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Hagyja figyelmen kívül a fenti gazdagépek és tartományok proxykonfigurációit</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigurációs URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Biztonság</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>GYORS</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Elrejtett TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Védett EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation>Jelszó mentése ezen felhasználó számára</translation>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation>Jelszó mentése az összes felhasználó számára</translation>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Kérdezze meg mindig</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Letiltva</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Névtelen</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Hitelesítve</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Mindkettő</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatikus</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Verzió 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Verzió 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP hitelesítés</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Azonosság</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Jelszó beállítások</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privát kulcs</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA tanúsítvány</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Felhasználói tanúsítvány</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Névtelen Azonosító</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Ellátás</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC fájl</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Belső hitelesítés</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP verzió</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privát jelszó</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Érvénytelen jelszó</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Személyes</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Személyes</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Biztonság</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kulcs</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Szükséges biztonság</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Érvénytelen jelszó</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 Személyes</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 Vállalati</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation>WPA3 Személyes</translation>
    </message>
    <message>
        <source>Shared key</source>
        <translation>Közös kulcs</translation>
    </message>
    <message>
        <source>Open system</source>
        <translation>Nyitott rendszer</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Biztonság</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Hitelesítés</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Kulcs</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Haladó VPN</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Átjáró port testreszabása</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Átjáró port</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Az újratárgyalási intervallum testreszabása</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Újratárgyalási intervallum</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>LZO adattömörítés használata</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>TCP kapcsolat használata</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>TAP eszköz használata</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>MTU csatorna testreszabása</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>UDP töredékméret testreszabása </translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP töredék mérete</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Korlátozza a TCP MSS alagutat</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Hosztok véletlenszerű elrendezése</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>Haladó VPN</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (alapértelmezett)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Biztonságos (alap)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Gyenge</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T Amikor Elérhető (alapértelmezett)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T Mindig</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Letiltva</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH csoport 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH csoport 2 (alapértelmezett)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH Csoport 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Szerver (alapértelmezett)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH Csoport 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Tartomány</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Előállító</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Verzió</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Titkosítás</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT átjáró mód</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH csoport</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Elő titkosítás</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Helyi port</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Halott peer észlelés letiltása</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>IPsec engedélyezése</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Csoportnév</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Csoport azonosító</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Előre megosztott kulcs </translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 Algoritmusok</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 Algoritmusok</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA tanúsítvány</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Proxy</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Cisco trójai védelem engedélyezése</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD szkript</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Felhasználói tanúsítvány</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privát kulcs</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>FSID azonosítókulcs használata </translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Tanúsítványok (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Tanúsítványok jelszóval (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statikus kulcs</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Elmentve</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kérdezze meg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nem kötelező</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Hitelesítés típusa</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA tanúsítvány</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Felhasználói tanúsítvány</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privát kulcs</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Jelszó beállítások</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privát jelszó</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Kulcs irány testreszabása</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kulcs irány</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Távoli IP cím</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Helyi IP cím</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Minden elérhető (alap)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (Kevésbé biztonságos)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (Legbiztonságosabb)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>EAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>PAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>CHAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>MSCHAP hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>MSCHAPv2 hitelesítés visszautasítása</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Nincs BSD Adattömörítés</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Nincs Delflate adattömörítés </translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Nincs TCP fejléc tömörítés</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Nincs protokoll mező tömörítés</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Nincs cím/vezérlés tömörítés</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>PPP Echo csomagok küldése</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>MPPE használata</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Biztonság</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Állapotfüggő MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN állapota</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>VPN létrehozása</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>VPN beállítások importálása</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importálási hiba</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Fájl hiba</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proxy</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nem kötelező</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Proxy típusa</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Szerver IP cím</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Ha sikertelen, próbálkozzon újra a végtelenségig</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>CA fájl</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Tanúsítvánnyal kapcsolatos figyelmeztetések figyelmen kívül hagyása</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>TLS kiszolgálónév kiterjesztések használata</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN biztonság</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nincs</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Titkosírás</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC Hitelesítés</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Elmentve</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kérdezze meg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nem kötelező</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Jelszó beállítások</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT Tartomány</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN proxy</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Szerver IP cím</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privát kulcs</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH Ügynök</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Intelligens Kártya</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Előre megosztott kulcs </translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>CA tanúsítvány</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Hitelesítés típusa</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Felhasználói tanúsítvány</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Belső IP cím igénylése</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Az UDP tokozás kikényszerítése</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>IP Tömörítés Használata</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Engedélyezze az egyedi titkosítási javaslatokat</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS hitelesítés</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Kliens</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Szerver</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Tárgy egyezés</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Távoli tanúsítvány típusa</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Kulcs fájl</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Kulcs irány testreszabása</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Kulcs irány</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Érvénytelen átjáró</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Elmentve</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Kérdezze meg</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nem kötelező</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Átjáró</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Felhasználónév</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Jelszó beállítások</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Jelszó</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Csoportnév</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Csoport jelszó</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Hibrid hitelesítés használata</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>CA fájl</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Először a hálózati kábelt csatlakoztasd.</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Vezetékes hálózati kártya</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Hálózat hozzáadása</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Beállítások kiválasztása</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Vezeték nélküli kártya</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Hotspot bezárása</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Először tiltsa le a hotspotot, ha vezeték nélküli hálózathoz szeretne csatlakozni</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Kapcsolódás rejtett hálózathoz</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>Vezeték nélküli hálózat</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nem kötött</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Kötelező</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Eszköz MAC címe</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>MTU testreszabása</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>